@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: doc2ipf.c,v 1.23 2012/05/21 20:39:20 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - doc2ipf.c */
 
 /*[
@@ -62,10 +58,10 @@ static char *RCSid() { return RCSid("$Id: doc2ipf.c,v 1.23 2012/05/21 20:39:20 s
 #define MAX_COL 6
 
 /* From xref.c */
-extern void *xmalloc __PROTO((size_t));
+extern void *xmalloc(size_t);
 
-void convert __PROTO((FILE *, FILE *));
-void process_line __PROTO((char *, FILE *));
+void convert(FILE *, FILE *);
+void process_line(char *, FILE *);
 
 /* malloc's are not being checked ! */
 
