@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: doc2rnh.c,v 1.18 2011/12/08 20:53:03 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - doc2rnh.c */
 
 /*[
@@ -38,7 +34,7 @@ static char *RCSid() { return RCSid("$Id: doc2rnh.c,v 1.18 2011/12/08 20:53:03 s
  * doc2rnh.c  -- program to convert Gnuplot .DOC format to
  *               Digital Standard Runoff for VMS HELP files
  *               (gnuplot.doc, including the terminal documentation
- *                is no longer formated for VMS HELP by default)
+ *                is no longer formatted for VMS HELP by default)
  *
  * From hlp2ms by Thomas Williams
  *
@@ -74,13 +70,13 @@ extern TBOOLEAN single_top_level;
 #define LINE_SKIP		3
 #define DSR_RM		70
 
-void init __PROTO((FILE *));
-void convert __PROTO((FILE *, FILE *));
-void process_line __PROTO((char *, FILE *));
-void section __PROTO((char *, FILE *));
-void putrnh __PROTO((char *, FILE *));
-void putrnh_ __PROTO((char *, FILE *));
-void finish __PROTO((FILE *));
+void init(FILE *);
+void convert(FILE *, FILE *);
+void process_line(char *, FILE *);
+void section(char *, FILE *);
+void putrnh(char *, FILE *);
+void putrnh_(char *, FILE *);
+void finish(FILE *);
 
 static TBOOLEAN intable = FALSE;
 static TBOOLEAN rnh_table = FALSE;
@@ -182,7 +178,7 @@ process_line(char *line, FILE *b)
 /* most tables are simple; no flags means no protected characters
  * other than period (command indicator) in first column
  *
- * However, for ease of maintainence, two tables have sublevels
+ * However, for ease of maintenance, two tables have sublevels
  * and descriptions, corresponding to the printed table entries,
  * encapsulated by the table markers.  Therefore we need to
  * do some more work.
@@ -224,7 +220,7 @@ process_line(char *line, FILE *b)
 
 /*
  *  "." in first column is the DSR command character;
- *  therefore, include the preceeding " "
+ *  therefore, include the preceding " "
  */
 	    case '.':{
 		    putrnh(line, b);
