@@ -46,7 +46,7 @@
 ;; text stream.  It seems much more efficient in this context to treat
 ;; it as a buffer.  All of the work is done by the function
 ;; `d2t-doc-to-texi'.  Each of the conversion chores is handled by an
-;; individual function.  Each of thse functions is very similar in
+;; individual function.  Each of these functions is very similar in
 ;; structure.  They start at the top of the buffer, search forward for
 ;; a line matching the text element being converted, perform the
 ;; replacement in place, and move on until the end of the buffer.
@@ -74,7 +74,7 @@
 ;;
 ;; This will start emacs in batch mode, load this file, run the
 ;; converter, then quit.  This takes about 30 seconds my 133 MHz
-;; Pentium.  It also sends a large number of mesages to stderr, so you
+;; Pentium.  It also sends a large number of messages to stderr, so you
 ;; may want to redirect stderr to /dev/null or to a file.
 ;;
 ;; Then you can do
@@ -160,7 +160,7 @@ If PATTERN is omitted, it defaults to \"[ \\f\\t\\n\\r\\v]+\"."
 @setchapternewpage odd
 @c %**end of header
 
-@c define the command and options indeces
+@c define the command and options indices
 @defindex cm
 @defindex op
 @defindex tm
@@ -298,8 +298,6 @@ Major contributors (alphabetic order):
 	"metapost"
 	"mgr"
 	"mif"
-	"next"
-	"openstep"
 	"pbm"
 	"pc"
 	"pdf"
@@ -309,7 +307,6 @@ Major contributors (alphabetic order):
 	"pstricks"
 	"qms"
 	"regis"
-	"sun"
 	"svg"
 	"t410x"
 	"table"
@@ -399,6 +396,7 @@ particular conversion chore."
   ;; convert the buffer from doc to texi, one element at a time
   (message "Converting to texinfo ...")
   (d2t-braces-atsigns)   ;; this must be the first conversion function
+  (d2t-transitem)        ;; translate new list item
   (d2t-comments)         ;; delete comments
   (d2t-sectioning)       ;; chapters, sections, etc
   (d2t-get-eldoc-strings)
@@ -451,13 +449,11 @@ particular conversion chore."
   '(("linux" "linux")
     ("canvas" "canvas")
     ("lua" "lua" "tikz")
-    ("mac" "mac" "openstep")
+    ("mac" "mac")
     ("beos" "be")
     ("dos" "emxvga" "djsvga" "fg" "pc")
     ("windows" "win")
-    ("next" "next")
     ("os2" "pm" "emxvga")
-    ("sun" "sun")
     ("vms" "vws"))
 
   "Additional terminals to add to the converted gnuplot.info file.
@@ -753,6 +749,23 @@ comment out the multi-word ? entries."
 	  (beginning-of-line)
 	  (insert "@c ")))) ))
 
+(defun d2t-transitem ()
+  "Translation lines beginning with #start, #end, #b, and ##.
+These lines makes a itemized list."
+  (and d2t-verbose (message "  Doing d2t-transitem ..."))
+  (save-excursion
+    (while (re-search-forward "^#start" (point-max) "to_end")
+      (replace-match "@itemize @bullet" t))
+    (goto-char (point-min))
+    (while (re-search-forward "^#end" (point-max) "to_end")
+      (replace-match "@end itemize" t))
+    (goto-char (point-min))
+    (while (re-search-forward "^#b " (point-max) "to_end")
+      (replace-match "@item\n " t))
+    (goto-char (point-min))
+    (while (re-search-forward "^##" (point-max) "to_end")
+      (replace-match "" t))))
+
 (defun d2t-comments ()
   "Delete comments and lines beginning with # or %.
 # and % lines are used in converting tables into various formats.
