@@ -911,7 +911,7 @@ regress_finalize(int iter, double chisq, double last_chisq, double lambda, doubl
     }
     if (fit_covarvariables) {
 	/* first, remove all previous covariance variables */
-	del_udv_by_name("FIT_COV_*", TRUE);
+	del_udv_by_name("FIT_COV_", TRUE);
 	for (i = 0; i < num_params; i++) {
 	    for (j = 0; j < i; j++) {
 		setvarcovar(par_name[i], par_name[j], 0.0);
@@ -1597,6 +1597,7 @@ fit_command()
     int token1, token2, token3;
     int fit_token;
     char *tmp, *file_name;
+    char *viafile;
     TBOOLEAN zero_initial_value;
     AXIS *fit_xaxis, *fit_yaxis, *fit_zaxis;
 
@@ -2127,14 +2128,13 @@ fit_command()
      * input line.  If it were wrapped in lf_push()/lf_pop() we could use
      * the normal gnuplot parsing routines keyed off c_token.
      */
-    if (isstringvalue(c_token)) {	/* It's a parameter *file* */
+    if ((viafile = try_to_get_string())) {	/* It's a parameter *file* */
 	TBOOLEAN fixed;
 	double tmp_par;
 	char c='\0', *s;
 	char sstr[MAX_LINE_LEN + 1];
 
-	char *viafile = try_to_get_string();
-	if (!viafile || !(via_f = loadpath_fopen(viafile, "r")))
+	if (!(via_f = loadpath_fopen(viafile, "r")))
 	    Eex2("could not read parameter-file \"%s\"", viafile);
 	if (!fit_suppress_log)
 	    fprintf(log_f, "fitted parameters and initial values from file: %s\n\n", viafile);
