@@ -131,6 +131,14 @@ f_pop(union argument *x)
 	gpfree_string(&dummy);
 }
 
+void
+f_nop(union argument *x)
+{
+    /* Presence of NOP in an action table serves as a barrier
+     * at the end of a ternary operation sequence.
+     */
+}
+
 void
 f_pushd2(union argument *x)
 {
@@ -1453,6 +1461,8 @@ f_index(union argument *arg)
 	i = index.v.int_val;
     else if (index.type == CMPLX)
 	i = floor(index.v.cmplx_val.real);
+    else
+	int_error(NO_CARET, "non-numeric array index");
 
     if (array.type == ARRAY) {
 	if (i <= 0 || i > array.v.value_array[0].v.int_val)
