@@ -837,6 +837,7 @@ parse_conditional_expression()
 	at->actions[savepc1].arg.j_arg = at->a_count - savepc1;
 	parse_expression();
 	at->actions[savepc2].arg.j_arg = at->a_count - savepc2;
+	add_action(NOP);
 	parse_recursion_level++;
     }
 }
@@ -1072,13 +1073,18 @@ parse_unary_expression()
 	parse_unary_expression();
 	/* Collapse two operations PUSHC <pos-const> + UMINUS
 	 * into a single operation PUSHC <neg-const>
+	 * Oct 2021: invalid if the previous constant is the else part of a conditional
+	 *           NOP barrier hides the PUSHC to prevent this
 	 */
 	previous = &(at->actions[at->a_count-1]);
-	if (previous->index == PUSHC &&  previous->arg.v_arg.type == INTGR) {
-	    previous->arg.v_arg.v.int_val = -previous->arg.v_arg.v.int_val;
-	} else if (previous->index == PUSHC &&  previous->arg.v_arg.type == CMPLX) {
-	    previous->arg.v_arg.v.cmplx_val.real = -previous->arg.v_arg.v.cmplx_val.real;
-	    previous->arg.v_arg.v.cmplx_val.imag = -previous->arg.v_arg.v.cmplx_val.imag;
+	if (previous->index == PUSHC) {
+	    if (previous->arg.v_arg.type == INTGR) {
+		previous->arg.v_arg.v.int_val = -previous->arg.v_arg.v.int_val;
+	    } else if (previous->arg.v_arg.type == CMPLX) {
+		previous->arg.v_arg.v.cmplx_val.real = -previous->arg.v_arg.v.cmplx_val.real;
+		previous->arg.v_arg.v.cmplx_val.imag = -previous->arg.v_arg.v.cmplx_val.imag;
+	    } else
+		(void) add_action(UMINUS);
 	} else
 	    (void) add_action(UMINUS);
     } else if (equals(c_token, "+")) {	/* unary + is no-op */
