@@ -1,7 +1,3 @@
-/*
- * $Id: tabulate.h,v 1.2.4.1 2017/07/20 18:32:13 sfeam Exp $
- */
-
 /* GNUPLOT - tabulate.h */
 
 #ifndef GNUPLOT_TABULATE_H
@@ -11,13 +7,14 @@
 
 /* Routines in tabulate.c needed by other modules: */
 
-void print_table __PROTO((struct curve_points * first_plot, int plot_num));
-void print_3dtable __PROTO((int pcount));
-TBOOLEAN tabulate_one_line __PROTO((double v[], struct value str[], int ncols));
+void print_table(struct curve_points * first_plot, int plot_num);
+void print_3dtable(int pcount);
+TBOOLEAN tabulate_one_line(double v[], struct value str[], int ncols);
 
 extern FILE *table_outfile;
 extern udvt_entry *table_var;
 extern TBOOLEAN table_mode;
 extern char *table_sep;
+extern struct at_type *table_filter_at;
 
 #endif /* GNUPLOT_TABULATE_H */
